/**
 * MIT License
 *
 * Copyright (c) 2017 Trifork
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in all
 * copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 * SOFTWARE.
 */
package dk.sds.ecpr2.webservice;

import dk.sds.ecpr2._2017._10._01.*;
import dk.sds.ecpr2.domain.OIDVO;
import dk.sds.ecpr2.service.ECPR2Service;
import dk.sds.ecpr2.util.FaultCode;
import dk.sds.ecpr2.webservice.mapping.ToXMLMapper;
import org.apache.cxf.annotations.SchemaValidation;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import javax.jws.WebService;
import javax.xml.ws.BindingType;
import java.util.List;

import static javax.xml.ws.soap.SOAPBinding.SOAP11HTTP_BINDING;


@WebService(name = "ECPR2MasterDataPortType", targetNamespace = "http://sds.dk/ecpr2/2017/10/01/")
@BindingType(value = SOAP11HTTP_BINDING)
@SchemaValidation(type = SchemaValidation.SchemaValidationType.BOTH)
@Service
public class ECPR2MasterDataWebServiceImpl extends AbstractWebService implements ECPR2MasterDataPortType {

    @Autowired
    private ECPR2Service businessService;

    @Autowired
    ToXMLMapper responseMapper;

    @Override
    public GetOIDsResponse getOIDs20171001(GetOIDsRequest request) throws DGWSFault {
        final GetOIDsResponse response = new ObjectFactory().createGetOIDsResponse();
        try {
            if (request != null) {
                List<OIDVO> list = businessService.getOIDs();
                response.getOIDS().addAll(responseMapper.mapOIDs(list));
            }
        } catch (Exception e) {
            commonExceptionHandler(e, FaultCode.GENERAL_ERROR, FaultCode.GENERAL_ERROR);
        }
        return response;
    }
}
